pub fn sqlite_transient() -> sqlite3_destructor_typeExpand description
Returns the SQLITE_TRANSIENT destructor value.
This value tells SQLite to immediately copy any bound string or blob data. It is the safest option when the source data’s lifetime is uncertain.